"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTorrentsRouter = void 0;
const express_1 = require("express");
const http_errors_1 = require("http-errors");
const validation_1 = require("../helpers/validation");
const helpers_1 = require("../helpers");
function torrentToJson(v, domain, encodeToken) {
    return {
        name: v.name,
        infoHash: v.infoHash,
        downloadSpeed: v.getDownloadSpeed(),
        downloaded: v.getDownloaded(),
        link: v.link,
        started: v.created.getTime(),
        updated: v.updated.getTime(),
        files: v.files.map((f) => ({
            name: f.name,
            path: f.path,
            type: f.type,
            length: f.length,
            stream: `${domain}${helpers_1.getSteamUrl(v.link, f.path, encodeToken)}`,
        })),
        playlist: `${domain}${helpers_1.getPlaylistUrl(v.link, encodeToken)}`,
    };
}
function getTorrentsRouter(config, _logger, client) {
    const encodeToken = config.security.streamApi.key || config.security.apiKey;
    return express_1.Router()
        .post('/torrents', async (req, res) => {
        const domain = req.protocol + '://' + req.get('host');
        const link = validation_1.validateString(req.query.torrent, 'torrent');
        const torrent = await client.addTorrent(link);
        res.json(torrentToJson(torrent, domain, encodeToken));
    })
        .get('/torrents', (req, res) => {
        const domain = req.protocol + '://' + req.get('host');
        return res.json(client.getTorrents().map((v) => torrentToJson(v, domain, encodeToken)));
    })
        .get('/torrents/:id', (req, res) => {
        const domain = req.protocol + '://' + req.get('host');
        const torrent = client.getTorrent(validation_1.validateString(req.params.id, 'id'));
        if (torrent) {
            return res.json(torrentToJson(torrent, domain, encodeToken));
        }
        throw new http_errors_1.NotFound();
    });
}
exports.getTorrentsRouter = getTorrentsRouter;
